summaryrefslogtreecommitdiffstats
path: root/xlators/performance/md-cache
diff options
context:
space:
mode:
Diffstat (limited to 'xlators/performance/md-cache')
-rw-r--r--xlators/performance/md-cache/src/md-cache.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/xlators/performance/md-cache/src/md-cache.c b/xlators/performance/md-cache/src/md-cache.c
index d70fa6a8d1a..36cedc64d70 100644
--- a/xlators/performance/md-cache/src/md-cache.c
+++ b/xlators/performance/md-cache/src/md-cache.c
@@ -38,8 +38,8 @@ struct mdc_statistics {
uint64_t negative_lookup; /* No. of negative lookups */
uint64_t nameless_lookup; /* No. of negative lookups that were sent
sent to bricks */
- uint64_t stat_invals; /* No. of invalidates recieved from upcall*/
- uint64_t xattr_invals; /* No. of invalidates recieved from upcall*/
+ uint64_t stat_invals; /* No. of invalidates received from upcall*/
+ uint64_t xattr_invals; /* No. of invalidates received from upcall*/
uint64_t need_lookup; /* No. of lookups issued, because other xlators
* requested for explicit lookup */
gf_lock_t lock;
@@ -2545,9 +2545,9 @@ mdc_priv_dump (xlator_t *this)
conf->mdc_counter.nameless_lookup);
gf_proc_dump_write("negative_lookup_count", "%"PRId64,
conf->mdc_counter.negative_lookup);
- gf_proc_dump_write("stat_invalidations_recieved", "%"PRId64,
+ gf_proc_dump_write("stat_invalidations_received", "%"PRId64,
conf->mdc_counter.stat_invals);
- gf_proc_dump_write("xattr_invalidations_recieved", "%"PRId64,
+ gf_proc_dump_write("xattr_invalidations_received", "%"PRId64,
conf->mdc_counter.xattr_invals);
return 0;